@@ -2,8 +2,8 @@ use crate::attributes::{parse_attributes, Attributes};
 use proc_macro2::TokenStream;
 use quote::{quote, quote_spanned};
 use syn::{
-    parse_quote, punctuated::Punctuated, spanned::Spanned, Data, DeriveInput, Error, Fields, Ident,
-    Index, Token, WherePredicate, Generics,
+    parse_quote, punctuated::Punctuated, spanned::Spanned, Data, DeriveInput, Error, Fields,
+    Generics, Ident, Index, Token, WherePredicate,
 };
 
 pub fn derive(input: DeriveInput) -> Result<TokenStream, Error> {
@@ -72,7 +72,7 @@ fn derive_deserialize_impl(
                 quote! {
                     impl #impl_generics Deserialize<#name #ty_generics, __D> for Archived<#name #ty_generics> #deserialize_where {
                         #[inline]
-                        fn deserialize(&self, deserializer: &mut __D) -> Result<#name #ty_generics, __D::Error> {
+                        fn deserialize(&self, deserializer: &mut __D) -> core::result::Result<#name #ty_generics, __D::Error> {
                             Ok(#name {
                                 #(#deserialize_fields,)*
                             })
@@ -104,7 +104,7 @@ fn derive_deserialize_impl(
                 quote! {
                     impl #impl_generics Deserialize<#name #ty_generics, __D> for Archived<#name #ty_generics> #deserialize_where {
                         #[inline]
-                        fn deserialize(&self, deserializer: &mut __D) -> Result<#name #ty_generics, __D::Error> {
+                        fn deserialize(&self, deserializer: &mut __D) -> core::result::Result<#name #ty_generics, __D::Error> {
                             Ok(#name(
                                 #(#deserialize_fields,)*
                             ))
@@ -115,7 +115,7 @@ fn derive_deserialize_impl(
             Fields::Unit => quote! {
                 impl #impl_generics Deserialize<#name #ty_generics, __D> for Archived<#name #ty_generics> #where_clause {
                     #[inline]
-                    fn deserialize(&self, _: &mut __D) -> Result<#name #ty_generics, __D::Error> {
+                    fn deserialize(&self, _: &mut __D) -> core::result::Result<#name #ty_generics, __D::Error> {
                         Ok(#name)
                     }
                 }
@@ -201,7 +201,7 @@ fn derive_deserialize_impl(
             quote! {
                 impl #impl_generics Deserialize<#name #ty_generics, __D> for Archived<#name #ty_generics> #deserialize_where {
                     #[inline]
-                    fn deserialize(&self, deserializer: &mut __D) -> Result<#name #ty_generics, __D::Error> {
+                    fn deserialize(&self, deserializer: &mut __D) -> core::result::Result<#name #ty_generics, __D::Error> {
                         Ok(match self {
                             #(#deserialize_variants,)*
                         })
@@ -294,7 +294,7 @@ fn derive_deserialize_copy_impl(
             quote! {
                 impl #impl_generics Deserialize<#name #ty_generics, __D> for Archived<#name #ty_generics> #deserialize_where {
                     #[inline]
-                    fn deserialize(&self, _: &mut __D) -> Result<Self, __D::Error> {
+                    fn deserialize(&self, _: &mut __D) -> core::result::Result<Self, __D::Error> {
                         Ok(*self)
                     }
                 }
@@ -335,7 +335,7 @@ fn derive_deserialize_copy_impl(
             quote! {
                 impl #impl_generics Deserialize<#name #ty_generics, __D> for Archived<#name #ty_generics> #deserialize_where {
                     #[inline]
-                    fn deserialize(&self, _: &mut __D) -> Result<Self, __D::Error> {
+                    fn deserialize(&self, _: &mut __D) -> core::result::Result<Self, __D::Error> {
                         Ok(*self)
                     }
                 }
