@@ -2,8 +2,8 @@ use crate::attributes::{parse_attributes, Attributes};
 use proc_macro2::TokenStream;
 use quote::{quote, quote_spanned};
 use syn::{
-    parse_quote, punctuated::Punctuated, spanned::Spanned, Data, DeriveInput, Error, Fields, Ident,
-    Index, Token, WherePredicate, Generics,
+    parse_quote, punctuated::Punctuated, spanned::Spanned, Data, DeriveInput, Error, Fields,
+    Generics, Ident, Index, Token, WherePredicate,
 };
 
 pub fn derive(input: DeriveInput) -> Result<TokenStream, Error> {
@@ -74,7 +74,7 @@ fn derive_serialize_impl(
                 quote! {
                     impl #impl_generics Serialize<__S> for #name #ty_generics #serialize_where {
                         #[inline]
-                        fn serialize(&self, serializer: &mut __S) -> Result<Self::Resolver, __S::Error> {
+                        fn serialize(&self, serializer: &mut __S) -> core::result::Result<Self::Resolver, __S::Error> {
                             Ok(#resolver {
                                 #(#resolver_values,)*
                             })
@@ -103,7 +103,7 @@ fn derive_serialize_impl(
                 quote! {
                     impl #impl_generics Serialize<__S> for #name #ty_generics #serialize_where {
                         #[inline]
-                        fn serialize(&self, serializer: &mut __S) -> Result<Self::Resolver, __S::Error> {
+                        fn serialize(&self, serializer: &mut __S) -> core::result::Result<Self::Resolver, __S::Error> {
                             Ok(#resolver(
                                 #(#resolver_values,)*
                             ))
@@ -115,7 +115,7 @@ fn derive_serialize_impl(
                 quote! {
                     impl #impl_generics Serialize<__S> for #name #ty_generics #where_clause {
                         #[inline]
-                        fn serialize(&self, serializer: &mut __S) -> Result<Self::Resolver, __S::Error> {
+                        fn serialize(&self, serializer: &mut __S) -> core::result::Result<Self::Resolver, __S::Error> {
                             Ok(#resolver)
                         }
                     }
@@ -198,7 +198,7 @@ fn derive_serialize_impl(
             quote! {
                 impl #impl_generics Serialize<__S> for #name #ty_generics #serialize_where {
                     #[inline]
-                    fn serialize(&self, serializer: &mut __S) -> Result<Self::Resolver, __S::Error> {
+                    fn serialize(&self, serializer: &mut __S) -> core::result::Result<Self::Resolver, __S::Error> {
                         Ok(match self {
                             #(#serialize_arms,)*
                         })
@@ -283,7 +283,7 @@ fn derive_serialize_copy_impl(
             quote! {
                 impl #impl_generics Serialize<__S> for #name #ty_generics #copy_where {
                     #[inline]
-                    fn serialize(&self, serializer: &mut __S) -> Result<Self::Resolver, __S::Error> {
+                    fn serialize(&self, serializer: &mut __S) -> core::result::Result<Self::Resolver, __S::Error> {
                         Ok(())
                     }
                 }
@@ -336,7 +336,7 @@ fn derive_serialize_copy_impl(
             quote! {
                 impl #impl_generics Serialize<__S> for #name #ty_generics #copy_where {
                     #[inline]
-                    fn serialize(&self, serializer: &mut __S) -> Result<Self::Resolver, __S::Error> {
+                    fn serialize(&self, serializer: &mut __S) -> core::result::Result<Self::Resolver, __S::Error> {
                         Ok(())
                     }
                 }
